package com.ebaiyihui.family.doctor.server.controller;

import com.alibaba.fastjson.JSONObject;
import com.ebaiyihui.family.doctor.common.bo.ImMessageDTO;
import com.ebaiyihui.family.doctor.common.dto.SendImMsgDTO;
import com.ebaiyihui.family.doctor.server.service.ImMsgTemplateService;
import com.ebaiyihui.family.doctor.server.util.RedisUtil;
import com.ebaiyihui.framework.response.BaseResponse;
import io.swagger.annotations.Api;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.BindingResult;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import java.util.Objects;

/**
 * @ClassName: ImMsgTemplateController
 * @Author:yanliang
 * @Date:2024/3/15 10:07
 * @Description
 */
@RestController
@RequestMapping("/imMsgTemplate")
@Api(tags = "消息发送API")
@Slf4j
public class ImMsgTemplateController {

    @Autowired
    private ImMsgTemplateService imMsgTemplateService;

    @Autowired
    private RedisUtil redisUtil;

    private static final String JTYS_SEND_IM_MESSAGE = "jtys_send_im_message_";

    private static final Integer OUT_TIME = 10 * 60;

    @RequestMapping(value = "/sendImMsg", method = RequestMethod.POST)
    public BaseResponse<String> sendImMsg(@RequestBody SendImMsgDTO reqVo,
                                          BindingResult bindingResult) {

        BaseResponse<String> response = null;
        try {
            Object sendImMsgKey = redisUtil.get(JTYS_SEND_IM_MESSAGE + reqVo.getAdmId() + "_" + reqVo.getType());

            if (Objects.isNull(sendImMsgKey)) {
                response = imMsgTemplateService.sendImMsg(reqVo);
                redisUtil.set(String.valueOf(sendImMsgKey), JSONObject.toJSONString(reqVo), OUT_TIME);
            }
        } catch (Exception e) {

            return BaseResponse.error(e.getMessage());
        }
        return BaseResponse.success("消息推送成功");
    }

    @RequestMapping(value = "/unReadMsgCount", method = RequestMethod.POST)
    public BaseResponse<String> unReadMsgCount(@RequestBody ImMessageDTO imMessageDTO,
                                               BindingResult bindingResult) {

        BaseResponse<String> response = null;
        try {
            response = imMsgTemplateService.unReadMsgCount(imMessageDTO);
        } catch (Exception e) {
            return BaseResponse.error(e.getMessage());
        }
        return BaseResponse.success("消息推送成功");
    }
}
