package com.ebaiyihui.family.doctor.server.rabbitmq;

import com.ebaiyihui.family.doctor.common.dto.NotifyConsultDataDTO;
import com.ebaiyihui.family.doctor.server.common.constants.CommonConstants;
import com.ebaiyihui.family.doctor.server.common.enums.StatusEnum;
import com.ebaiyihui.family.doctor.server.config.RabbitMqConfig;
import com.ebaiyihui.family.doctor.server.entity.MobileBenefitPackageEntity;
import com.ebaiyihui.family.doctor.server.entity.PatientSignEntity;
import com.ebaiyihui.family.doctor.server.mapper.MobileBenefitPackageMapper;
import com.ebaiyihui.family.doctor.server.mapper.PatientSignMapper;
import com.ebaiyihui.family.doctor.server.util.DateUtils;
import com.ebaiyihui.family.doctor.server.util.ThirdOrderPushUtil;
import com.ebaiyihui.family.doctor.server.vo.OrderTaskVo;
import lombok.extern.slf4j.Slf4j;
import org.springframework.amqp.rabbit.annotation.RabbitListener;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.messaging.handler.annotation.Payload;
import org.springframework.stereotype.Component;
import org.springframework.util.ObjectUtils;

import java.util.Date;

/**
 * @ClassName: RabbitConsumer
 * @Author:yanliang
 * @Date:2024/3/20 11:19
 * @Description
 */
@Slf4j
@Component
public class RabbitConsumer {

    @Autowired
    private PatientSignMapper patientSignMapper;

    @Autowired
    private MobileBenefitPackageMapper mobileBenefitPackageMapper;

    @Autowired
    private ThirdOrderPushUtil thirdOrderPushUtil;

    @RabbitListener(queues = RabbitMqConfig.ORDER_DELAY_QUEUE_1)
    public void orderDelayQueue1(@Payload OrderTaskVo orderTaskVo) {
        log.info("定时任务监听结果：{}", orderTaskVo.toString());
        try {
            String id = orderTaskVo.getId();
            log.info("【orderDelayQueue 监听的消息】 - 【消费时间】 - [{}]- 【订单ID】 - [{}]", new Date(), id);
            PatientSignEntity patientSignEntity = patientSignMapper.selectById(id);
            if (null == patientSignEntity) {
                return;
            }

            // 存在进行中订单则将订单状态改为失效
            if (StatusEnum.IN_CONSULTATION.getValue().equals(patientSignEntity.getStatus())) {
                patientSignEntity.setStatus(StatusEnum.FINISH_APPLY.getValue());
                patientSignMapper.updateById(patientSignEntity);

                MobileBenefitPackageEntity entity = mobileBenefitPackageMapper.queryByPhone(patientSignEntity.getPatientPhone(),
                        patientSignEntity.getPackageOrderId(), "1");
                if (!ObjectUtils.isEmpty(entity)) {
                    // 推送第三方权益使用
                    NotifyConsultDataDTO notifyConsultDataDTO = new NotifyConsultDataDTO();
                    notifyConsultDataDTO.setActivateOrderId(patientSignEntity.getPackageOrderId());
                    notifyConsultDataDTO.setConsultOrderNo(patientSignEntity.getAdmId());
                    notifyConsultDataDTO.setStatus(String.valueOf(StatusEnum.FINISH_APPLY.getValue()));
                    notifyConsultDataDTO.setProductId(entity.getProductId());
                    notifyConsultDataDTO.setPatientId(entity.getUserId());
                    notifyConsultDataDTO.setExpertName(patientSignEntity.getDoctorName());
                    notifyConsultDataDTO.setOrderDate(DateUtils.dateToFullString(patientSignEntity.getCreateTime()));
                    notifyConsultDataDTO.setSupplierCode(CommonConstants.SUPPLIER_CODE_JTYS);
                    thirdOrderPushUtil.syncBenefitUsedOrder(notifyConsultDataDTO, null);
                }
            }
        } catch (Exception e) {
            log.info("orderDelayQueue监听异常", e);
            return;
        }
    }
}
