package com.ebaiyihui.family.doctor.server.service.impl;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.doctoruser.api.pojo.base.dto.doctor.QueryPersonnelInfoReq;
import com.doctoruser.api.pojo.base.vo.doctor.PersonnelInfo;
import com.doctoruser.api.pojo.vo.UserInfoByDoctorIdRespVO;
import com.doctoruser.api.pojo.vo.UserInfoByUserIdRespVO;
import com.ebaiyihui.family.doctor.common.bo.Components;
import com.ebaiyihui.family.doctor.common.bo.ImMessageDTO;
import com.ebaiyihui.family.doctor.common.bo.MsgContent;
import com.ebaiyihui.family.doctor.common.dto.InfoListDTO;
import com.ebaiyihui.family.doctor.common.dto.SendImMsgDTO;
import com.ebaiyihui.family.doctor.common.dto.UnReadMsgDTO;
import com.ebaiyihui.family.doctor.server.common.enums.SignStatus;
import com.ebaiyihui.family.doctor.server.common.enums.StatusEnum;
import com.ebaiyihui.family.doctor.server.entity.ImMsgTemplateEntity;
import com.ebaiyihui.family.doctor.server.entity.PatientEntity;
import com.ebaiyihui.family.doctor.server.entity.PatientSignEntity;
import com.ebaiyihui.family.doctor.server.exception.BusinessException;
import com.ebaiyihui.family.doctor.server.feign.DoctorInfofeignClient;
import com.ebaiyihui.family.doctor.server.feign.UserApiFeignClient;
import com.ebaiyihui.family.doctor.server.mapper.ImMsgTemplateMapper;
import com.ebaiyihui.family.doctor.server.mapper.PatientMapper;
import com.ebaiyihui.family.doctor.server.mapper.PatientSignMapper;
import com.ebaiyihui.family.doctor.server.service.ImChatTemplate;
import com.ebaiyihui.family.doctor.server.service.ImMsgTemplateService;
import com.ebaiyihui.family.doctor.server.util.DateUtils;
import com.ebaiyihui.family.doctor.server.util.JsonUtil;
import com.ebaiyihui.family.doctor.server.util.ThirdOrderPushUtil;
import com.ebaiyihui.framework.response.BaseResponse;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;

import java.util.*;
import java.util.stream.Collectors;

/**
 * @ClassName: ImMsgTemplateServiceImpl
 * @Author:yanliang
 * @Date:2024/3/15 10:06
 * @Description
 */
@Service
@Slf4j
public class ImMsgTemplateServiceImpl implements ImMsgTemplateService {

    @Autowired
    private UserApiFeignClient userApiFeignClient;

    @Autowired
    private DoctorInfofeignClient doctorInfofeignClient;

    @Autowired
    private ImChatTemplate imChatTemplate;

    @Autowired
    private PatientMapper patientMapper;

    @Autowired
    private ImMsgTemplateMapper imMsgTemplateMapper;

    @Autowired
    private PatientSignMapper patientSignMapper;

    @Autowired
    private ThirdOrderPushUtil thirdOrderPushUtil;

    @Async
    @Override
    public BaseResponse<String> sendImMsg(SendImMsgDTO sendImMsgDTO) {

        QueryWrapper<ImMsgTemplateEntity> wrapper = new QueryWrapper<>();
        ImMsgTemplateEntity imMsgTemplate = new ImMsgTemplateEntity();
        imMsgTemplate.setAppCode(sendImMsgDTO.getAppCode());
        imMsgTemplate.setOrganId(sendImMsgDTO.getOrganId());
        imMsgTemplate.setType(sendImMsgDTO.getType());
        wrapper.setEntity(imMsgTemplate);
        ImMsgTemplateEntity imMsgTemplateEntity = imMsgTemplateMapper.selectOne(wrapper);
        String components = imMsgTemplateEntity.getContent();
        MsgContent msgContent = JSON.parseObject(components, MsgContent.class);
        List<Components> componentsList = msgContent.getComponents().stream().sorted(Comparator.comparing(Components::getSort)).collect(Collectors.toList());
        Boolean flag = imChatTemplate.sendMsg(componentsList, sendImMsgDTO);
        if (!flag) {
            throw new BusinessException("消息推送失败");
        }
        return BaseResponse.success("消息推送成功");
    }

    @Override
    public BaseResponse<String> unReadMsgCount(ImMessageDTO imMessageDTO) {
        log.info("unReadMsgCount请求入参={}", imMessageDTO);
        QueryWrapper<PatientSignEntity> psWrapper = new QueryWrapper<>();
        PatientSignEntity patientSign = new PatientSignEntity();
        patientSign.setAdmId(imMessageDTO.getTreatmentId());
        patientSign.setSignStatus(SignStatus.SIGNED.getValue());
        patientSign.setStatus(StatusEnum.IN_CONSULTATION.getValue());
        psWrapper.setEntity(patientSign);
        PatientSignEntity patientSignEntity = patientSignMapper.selectOne(psWrapper);
        if (Objects.nonNull(patientSignEntity)) {
            // 获取医生基本信息
            QueryPersonnelInfoReq queryPersonnelInfoReq = new QueryPersonnelInfoReq();
            queryPersonnelInfoReq.setDoctorId(String.valueOf(patientSignEntity.getDoctorId()));
            BaseResponse<PersonnelInfo> doctorInfo = doctorInfofeignClient.queryPersonnelInfo(queryPersonnelInfoReq);
            // 调用用户系统查询医生userId
            UserInfoByUserIdRespVO userInfoByUserIdRespVO = queryDocAccountInfo(String.valueOf(patientSignEntity.getDoctorId()));
            if (userInfoByUserIdRespVO == null) {
                log.error("IM INFORM ERROR : 获取医生信息失败 doctorId：{}", String.valueOf(patientSignEntity.getDoctorId()));
                return BaseResponse.error("获取im医生账号信息失败！");
            }
            if (null == doctorInfo && !doctorInfo.isSuccess()) {
                log.error("IM INFORM ERROR : 获取医生信息失败 doctorId：{}", String.valueOf(patientSignEntity.getDoctorId()));
                return BaseResponse.error("获取im医生账号信息失败！");
            }
            String doctorUserId = userInfoByUserIdRespVO.getUserId();
            if (imMessageDTO.getSenderUserId().equals(doctorUserId)) {
                // 查询患者信息
                PatientEntity patientEntity = patientMapper.selectById(patientSignEntity.getPatientId());
                if (Objects.nonNull(patientEntity)) {
                    // 状态是离线则未读消息+1
                    if (patientEntity.getOnOfflineStatus().equals(-1)) {
                        patientEntity.setUnReadCount(patientEntity.getUnReadCount() + 1);
                    } else {
                        patientEntity.setUnReadCount(0);
                    }
                    patientMapper.updateById(patientEntity);
                    // 推送未读消息统计
                    UnReadMsgDTO unReadMsgDTO = new UnReadMsgDTO();
                    unReadMsgDTO.setPhone(patientSignEntity.getPatientPhone());
                    List<InfoListDTO> infoList = new ArrayList<>();
                    InfoListDTO infoListDTO = new InfoListDTO();
                    infoListDTO.setUserName(patientSignEntity.getPatientName());
                    infoListDTO.setDoctorId(String.valueOf(patientSignEntity.getDoctorId()));
                    infoListDTO.setMessageNum(String.valueOf(patientEntity.getUnReadCount()));
                    infoListDTO.setGroupId(imMessageDTO.getRoomNum());
                    String timestamp = "";
                    try {
                        Date timestampDate = DateUtils.parseDate(imMessageDTO.getMsgTime(), DateUtils.FULL_FORMAT);
                        timestamp = String.valueOf(timestampDate.getTime());
                    } catch (Exception e) {
                        log.error("日志转换异常", e);
                    }

                    infoListDTO.setTimestamp(timestamp);
                    infoList.add(infoListDTO);
                    unReadMsgDTO.setInfoList(infoList);
                    thirdOrderPushUtil.syncUnReadMsgCount(unReadMsgDTO);

                }
            }

        }

        return BaseResponse.success();
    }

    private UserInfoByUserIdRespVO queryDocAccountInfo(String doctorId) {

        BaseResponse<UserInfoByDoctorIdRespVO> response = userApiFeignClient.getUserInfoByDoctorId(doctorId);
        log.info("response:{}", JsonUtil.convertObject(response));

        UserInfoByUserIdRespVO userInfoByUserIdRespVO = new UserInfoByUserIdRespVO();
        if (response.isSuccess()) {

            userInfoByUserIdRespVO.setUserId(response.getData().getUserId());
            log.info("UserInfoByUserIdRespVO===>{}", JSON.toJSONString(userInfoByUserIdRespVO));
            return userInfoByUserIdRespVO;
        }

        return null;
    }
}
