package com.ebaiyihui.family.doctor.server.service.impl;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.ebaiyihui.family.doctor.common.dto.NotifyConsultDataDTO;
import com.ebaiyihui.family.doctor.common.dto.SendImMsgDTO;
import com.ebaiyihui.family.doctor.common.dto.SignedDoctorDTO;
import com.ebaiyihui.family.doctor.server.common.constants.CommonConstants;
import com.ebaiyihui.family.doctor.server.common.constants.ImConstants;
import com.ebaiyihui.family.doctor.server.common.enums.ImSignStatus;
import com.ebaiyihui.family.doctor.server.common.enums.SignStatus;
import com.ebaiyihui.family.doctor.server.common.enums.StatusEnum;
import com.ebaiyihui.family.doctor.server.entity.MobileBenefitPackageEntity;
import com.ebaiyihui.family.doctor.server.entity.PatientSignEntity;
import com.ebaiyihui.family.doctor.server.entity.ScheduleRecordEntity;
import com.ebaiyihui.family.doctor.server.entity.ServiceConfigEntity;
import com.ebaiyihui.family.doctor.server.exception.BusinessException;
import com.ebaiyihui.family.doctor.server.mapper.MobileBenefitPackageMapper;
import com.ebaiyihui.family.doctor.server.mapper.PatientSignMapper;
import com.ebaiyihui.family.doctor.server.mapper.ScheduleRecordMapper;
import com.ebaiyihui.family.doctor.server.mapper.ServiceConfigMapper;
import com.ebaiyihui.family.doctor.server.rabbitmq.RabbitProduct;
import com.ebaiyihui.family.doctor.server.service.GoEasyPushService;
import com.ebaiyihui.family.doctor.server.service.ImChatTemplate;
import com.ebaiyihui.family.doctor.server.service.ImMsgTemplateService;
import com.ebaiyihui.family.doctor.server.service.PatientService;
import com.ebaiyihui.family.doctor.server.util.DateUtils;
import com.ebaiyihui.family.doctor.server.util.ThirdOrderPushUtil;
import com.ebaiyihui.family.doctor.server.util.UUIDUtil;
import com.ebaiyihui.family.doctor.server.vo.OrderTaskVo;
import com.ebaiyihui.framework.response.BaseResponse;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;
import org.springframework.util.ObjectUtils;
import org.springframework.util.StringUtils;

import java.util.*;
import java.util.stream.Collectors;

/**
 * @ClassName: PatientServiceImpl
 * @Author:yanliang
 * @Date:2024/3/13 09:51
 * @Description
 */
@Service
@Slf4j
public class PatientServiceImpl implements PatientService {

    @Autowired
    private PatientSignMapper patientSignMapper;

    @Autowired
    private ServiceConfigMapper serviceConfigMapper;

    @Autowired
    private MobileBenefitPackageMapper mobileBenefitPackageMapper;

    @Autowired
    private ScheduleRecordMapper scheduleRecordMapper;

    @Autowired
    private ImMsgTemplateService imMsgTemplateService;

    @Autowired
    private GoEasyPushService goEasyPushService;

    @Autowired
    private ImChatTemplate imChatTemplate;

    @Autowired
    private ThirdOrderPushUtil thirdOrderPushUtil;

    @Autowired
    private RabbitProduct rabbitProduct;


    @Override
    public BaseResponse<String> signedDoctor(SignedDoctorDTO reqVo) {

        MobileBenefitPackageEntity entity = mobileBenefitPackageMapper.queryByPhone(reqVo.getPhone(), reqVo.getPackageOrderId(), null);
        log.info("entity={}", entity);
        if (ObjectUtils.isEmpty(entity)) {
            return BaseResponse.error("没有查询到有关权益");
        }

        String admId = UUIDUtil.getUUID();
        Date curDate = new Date();
        Date signEndTime = DateUtils.getAfterDay(curDate, CommonConstants.DAY);
        Date signStartTime = new Date();
        try {
            if (!StringUtils.isEmpty(entity.getBenefitsEndTime())) {
                signEndTime = DateUtils.parseDate(entity.getBenefitsEndTime(), DateUtils.FULL_FORMAT);
                signStartTime = DateUtils.parseDate(entity.getBenefitsStartTime(), DateUtils.FULL_FORMAT);
            }
        } catch (Exception e) {
            return BaseResponse.error("没有查询到有关权益");
        }
        Long doctorId = reqVo.getDoctorId();
        String doctorName = reqVo.getDoctorName();
        Long deptId = reqVo.getDeptId();
        String deptName = reqVo.getDeptName();

        PatientSignEntity oldPatientSignEntity = new PatientSignEntity();
        PatientSignEntity tempOldPatientSignEntity = new PatientSignEntity();
        // 改签或者排班医生获取签约的id
        if (!SignStatus.SIGNED.getValue().equals(reqVo.getSignStatus())) {
            QueryWrapper<PatientSignEntity> psWrapper = new QueryWrapper<>();
            PatientSignEntity patientSign = new PatientSignEntity();
            patientSign.setAdmId(reqVo.getAdmId());
            psWrapper.setEntity(patientSign);
            oldPatientSignEntity = patientSignMapper.selectOne(psWrapper);
            Date signCreateTime = oldPatientSignEntity.getCreateTime();
            BeanUtils.copyProperties(oldPatientSignEntity, tempOldPatientSignEntity);
            log.info("tempOldPatientSignEntity={}", tempOldPatientSignEntity);
            log.info("入参查询oldPatientSignEntity={}", oldPatientSignEntity);
            if (!oldPatientSignEntity.getSignId().equals(0L)) {
                QueryWrapper<PatientSignEntity> cpsWrapper = new QueryWrapper<>();
                PatientSignEntity cPatientSign = new PatientSignEntity();
                cPatientSign.setId(oldPatientSignEntity.getSignId());
                cpsWrapper.setEntity(cPatientSign);
                oldPatientSignEntity = patientSignMapper.selectOne(cpsWrapper);
                log.info("改签查询原始oldPatientSignEntity={}", oldPatientSignEntity);

            }
            // 改签查询原始签约信息
            if (SignStatus.CANCEL.getValue().equals(reqVo.getSignStatus())) {
                if (!tempOldPatientSignEntity.getSignId().equals(0L)) {
                    log.info("signCreateTime={}, signStartTime={}, signEndTime={}", signCreateTime, signStartTime, signEndTime);
                    if (signCreateTime.after(signStartTime) && signCreateTime.before(signEndTime)) {
                        return BaseResponse.error("已经有进行中的签约或者改签医生，不能再进行签约或者改签！！！");
                    }
                }
                // 处理换绑医生
                if ((!StringUtils.isEmpty(reqVo.getAdmId()) || !StringUtils.isEmpty(reqVo.getSignSeqId()))) {
                    if (Objects.nonNull(tempOldPatientSignEntity)) {
                        signEndTime = tempOldPatientSignEntity.getSignEndTime();
                        tempOldPatientSignEntity.setStatus(StatusEnum.FINISH_APPLY.getValue());
                        tempOldPatientSignEntity.setSignStatus(SignStatus.CANCEL.getValue());
                        tempOldPatientSignEntity.setSubStatus(2);
                        tempOldPatientSignEntity.setSignEndTime(curDate);
                        patientSignMapper.updateById(tempOldPatientSignEntity);
                    } else {
                        return BaseResponse.error("未查询到的签约医生，不能进行改签！！！");
                    }
                }


            } else if (SignStatus.NORMAL.getValue().equals(reqVo.getSignStatus())) { // 排班签约信息
                QueryWrapper<PatientSignEntity> nPsWrapper = new QueryWrapper<>();
                PatientSignEntity nPatientSign = new PatientSignEntity();
                nPatientSign.setSignId(oldPatientSignEntity.getId());
                nPatientSign.setStatus(StatusEnum.IN_CONSULTATION.getValue());
                nPatientSign.setSignStatus(SignStatus.NORMAL.getValue());
                nPsWrapper.setEntity(nPatientSign);
                PatientSignEntity patientSignEntity = patientSignMapper.selectOne(nPsWrapper);
                if (Objects.nonNull(patientSignEntity)) {
                    return BaseResponse.success(patientSignEntity.getAdmId());
                }

                // 查询排班医生信息
                ScheduleRecordEntity scheduleRecordEntity = getScheduleDoctor(reqVo.getPatientId(), reqVo.getPackageOrderId(), tempOldPatientSignEntity.getDoctorId());
                doctorId = Long.valueOf(scheduleRecordEntity.getDoctorId());
                doctorName = scheduleRecordEntity.getDoctorName();
                deptId = Long.valueOf(scheduleRecordEntity.getDeptId());
                deptName = scheduleRecordEntity.getDeptName();
            }
        } else { // 首次签约
            Integer signStatus = SignStatus.SIGNED.getValue();
            Integer status = StatusEnum.IN_CONSULTATION.getValue();
            List<PatientSignEntity> patientSignEntities = getPatientSignList(reqVo.getPhone(), reqVo.getPackageOrderId(),
                    signStatus, status);
            if (!patientSignEntities.isEmpty()) {
                if (SignStatus.SIGNED.getValue().equals(reqVo.getSignStatus())) {
                    return BaseResponse.error("已经有进行中的签约或者改签医生，不能再进行签约或者改签！！！");
                }
            }
        }

        PatientSignEntity patientSignEntity = new PatientSignEntity();
        patientSignEntity.setAdmId(admId);
        patientSignEntity.setAppCode(CommonConstants.APP_CODE);
        patientSignEntity.setOrganId(CommonConstants.ORGAN_CODE);
        patientSignEntity.setOrganName(CommonConstants.ORGAN_NAME);
        patientSignEntity.setDoctorId(doctorId);
        patientSignEntity.setDoctorName(doctorName);
        patientSignEntity.setDeptId(deptId);
        patientSignEntity.setDeptName(deptName);
        patientSignEntity.setSignStatus(SignStatus.CANCEL.getValue().equals(reqVo.getSignStatus()) ? SignStatus.SIGNED.getValue() : reqVo.getSignStatus());
        patientSignEntity.setPatientPhone(reqVo.getPhone());
        patientSignEntity.setCredNo(reqVo.getCredNo());
        patientSignEntity.setPatientId(reqVo.getPatientId());
        patientSignEntity.setPatientName(reqVo.getName());
        patientSignEntity.setPatientUserId(entity.getUserId());
        patientSignEntity.setStatus(StatusEnum.IN_CONSULTATION.getValue());
        patientSignEntity.setPackageOrderId(reqVo.getPackageOrderId());
        patientSignEntity.setSignEndTime(signEndTime);
        log.info("oldPatientSignEntity={}", oldPatientSignEntity);
        if (Objects.nonNull(oldPatientSignEntity)) {
            patientSignEntity.setSignId(oldPatientSignEntity.getId());
        }

        patientSignMapper.insert(patientSignEntity);

        //创建IM
        BaseResponse createImResponse = imChatTemplate.createImSession(patientSignEntity);
        if (!createImResponse.isSuccess()) {
            log.info("创建IM失败:{}", createImResponse.getMsg());
            throw new BusinessException("创建IM失败");
        }

        SendImMsgDTO sendImMsgDTO = new SendImMsgDTO();

        // 推送im主动消息
        sendImMsgDTO.setAdmId(admId);
        sendImMsgDTO.setAppCode(CommonConstants.APP_CODE);
        sendImMsgDTO.setOrganId(CommonConstants.ORGAN_CODE);
        sendImMsgDTO.setType(SignStatus.SIGNED.getValue().equals(reqVo.getSignStatus()) ? ImSignStatus.SIGN_SUC.getValue() :
                SignStatus.CANCEL.getValue().equals(reqVo.getSignStatus()) ? ImSignStatus.REISSUE_SUC.getValue() :
                        ImSignStatus.INQUIRY_SCH_DOC.getValue());

        //放入MQ任务,处理订单到时结束
        if ("0".equals(entity.getIsRenew()) || SignStatus.NORMAL.getValue().equals(reqVo.getSignStatus())) {
            OrderTaskVo orderTaskVo = new OrderTaskVo();
            orderTaskVo.setType(1);
            orderTaskVo.setId(String.valueOf(patientSignEntity.getId()));
            if ("0".equals(entity.getIsRenew())) {
                orderTaskVo.setExpireTime(DateUtils.secondBetween(signStartTime, signEndTime));
            }
            rabbitProduct.sendDelay(orderTaskVo);
        }

        // 推送第三方签名相关订单信息
        thirdOrderPushUtil.pushSignedOrder(String.valueOf(reqVo.getDoctorId()), reqVo.getPhone(),
                SignStatus.SIGNED.getValue().equals(reqVo.getSignStatus()) ? String.valueOf(patientSignEntity.getId()) :
                        String.valueOf(patientSignEntity.getSignId()),
                reqVo.getPackageOrderId(), reqVo.getSignStatus());

        imMsgTemplateService.sendImMsg(sendImMsgDTO);

        if (!SignStatus.NORMAL.getValue().equals(reqVo.getSignStatus())) {
            // 推送第三方权益使用
            NotifyConsultDataDTO notifyConsultDataDTO = new NotifyConsultDataDTO();
            notifyConsultDataDTO.setActivateOrderId(reqVo.getPackageOrderId());
            notifyConsultDataDTO.setConsultOrderNo(admId);
            notifyConsultDataDTO.setStatus(String.valueOf(StatusEnum.IN_CONSULTATION.getValue()));
            notifyConsultDataDTO.setProductId(entity.getProductId());
            notifyConsultDataDTO.setPatientId(entity.getUserId());
            notifyConsultDataDTO.setExpertName(reqVo.getDoctorName());
            notifyConsultDataDTO.setOrderDate(DateUtils.dateToFullString(patientSignEntity.getCreateTime()));
            notifyConsultDataDTO.setSupplierCode(CommonConstants.SUPPLIER_CODE_JTYS);
            thirdOrderPushUtil.syncBenefitUsedOrder(notifyConsultDataDTO, 10000L);

            if (SignStatus.CANCEL.getValue().equals(reqVo.getSignStatus())) {
                // 推送第三方权益使用
                NotifyConsultDataDTO notifyConsultDataDTO2 = new NotifyConsultDataDTO();
                notifyConsultDataDTO2.setActivateOrderId(reqVo.getPackageOrderId());
                notifyConsultDataDTO2.setConsultOrderNo(tempOldPatientSignEntity.getAdmId());
                notifyConsultDataDTO2.setStatus(String.valueOf(StatusEnum.FINISH_APPLY.getValue()));
                notifyConsultDataDTO2.setProductId(entity.getProductId());
                notifyConsultDataDTO2.setPatientId(entity.getUserId());
                notifyConsultDataDTO2.setExpertName(reqVo.getDoctorName());
                notifyConsultDataDTO2.setOrderDate(DateUtils.dateToFullString(patientSignEntity.getCreateTime()));
                notifyConsultDataDTO2.setSupplierCode(CommonConstants.SUPPLIER_CODE_JTYS);
                thirdOrderPushUtil.syncBenefitUsedOrder(notifyConsultDataDTO2, 10000L);
            }
        } else {
            if (Objects.nonNull(oldPatientSignEntity)) {
                sendImMsgDTO.setOldAdmId(oldPatientSignEntity.getAdmId());
            }

        }

        // 推送app提示语
        goEasyPushService.newOrderToReceive(admId);

        return BaseResponse.success(admId);
    }

    @Override
    public BaseResponse<PatientSignEntity> getSignedDoctor(SignedDoctorDTO reqVo) {
        QueryWrapper<PatientSignEntity> psWrapper = new QueryWrapper<>();
        PatientSignEntity patientSign = new PatientSignEntity();
        if (Objects.nonNull(reqVo.getAdmId())) {
            patientSign.setAdmId(reqVo.getAdmId());
        }
        if (Objects.nonNull(reqVo.getPhone())) {
            patientSign.setPatientPhone(reqVo.getPhone());
        }
        psWrapper.setEntity(patientSign);
        if (Objects.nonNull(reqVo.getPhone())) {
            psWrapper.orderByDesc("create_time");
            psWrapper.last("limit 1");
        }

        PatientSignEntity patientSignEntity = patientSignMapper.selectOne(psWrapper);
        if (null == patientSignEntity) {
            throw new BusinessException("未查询到签约医生信息！");
        }

        return BaseResponse.success(patientSignEntity);
    }

    /**
     * 随访查询一个排班医生
     *
     * @param patientId
     * @return
     */
    public ScheduleRecordEntity getScheduleDoctor(String patientId, String packageOrderId, Long doctorId) {
        String date = DateUtils.dateToSimpleString(new Date());
        String hourAndSecond = DateUtils.getHourAndSecond();
        QueryWrapper<PatientSignEntity> psWrapper = new QueryWrapper<>();
        PatientSignEntity patientSign = new PatientSignEntity();
        patientSign.setPatientId(patientId);
        patientSign.setPackageOrderId(packageOrderId);
        patientSign.setSignStatus(SignStatus.NORMAL.getValue());
        patientSign.setStatus(StatusEnum.IN_CONSULTATION.getValue());
        psWrapper.setEntity(patientSign);
        List<PatientSignEntity> patientSignEntities = patientSignMapper.selectList(psWrapper);
        if (!CollectionUtils.isEmpty(patientSignEntities)) {
            throw new BusinessException("已有进行中排班医生沟通,请勿重复点击");
        }
        // 查询排班医生信息
        List<ScheduleRecordEntity> scheduleRecordEntities = scheduleRecordMapper.selectByDate(String.valueOf(CommonConstants.ORGAN_CODE), 5, date, 1, hourAndSecond, null);
        log.info("当前排班医生:{},传进来过滤的医生id={}", JSON.toJSONString(scheduleRecordEntities), doctorId);

        if (!CollectionUtils.isEmpty(scheduleRecordEntities)) {
            scheduleRecordEntities = scheduleRecordEntities.stream().filter(scheduleRecordEntity -> !scheduleRecordEntity.getDoctorId().equals(String.valueOf(doctorId))).collect(Collectors.toList());
        }

        log.info("过滤之后的医生:{}", JSON.toJSONString(scheduleRecordEntities));

        if (CollectionUtils.isEmpty(scheduleRecordEntities)) {
            throw new BusinessException("服务时间为08:00-20:00，您发起的咨询暂时没有医生回答，医生上班后会第一时间回复您。");
        }

        ScheduleRecordEntity scheduleRecordEntity = new ScheduleRecordEntity();

        Random random = new Random();
        int i = random.nextInt(scheduleRecordEntities.size() + 1);
        if (i == 0) {
            i = i + 1;
        }
        scheduleRecordEntity = scheduleRecordEntities.get(i - 1);

        log.info("查询当前排班医生doctorId={}", scheduleRecordEntity.getDoctorId());
        // 查询值班的医生是否在线，如果不在线则强制在线，以排班信息为准
        QueryWrapper<ServiceConfigEntity> queryWrapper = new QueryWrapper<>();
        ServiceConfigEntity wrapperEntity = new ServiceConfigEntity();
        wrapperEntity.setOrganId(String.valueOf(CommonConstants.ORGAN_CODE));
        wrapperEntity.setAppCode(CommonConstants.APP_CODE);
        wrapperEntity.setDoctorId(scheduleRecordEntity.getDoctorId());
        wrapperEntity.setServiceCode(ImConstants.IM_QUERY_ACCOUNT_CODE);
        wrapperEntity.setStatus(1);
        queryWrapper.setEntity(wrapperEntity);
        queryWrapper.last("limit 1");
        ServiceConfigEntity serviceConfigEntity = serviceConfigMapper.selectOne(queryWrapper);
        log.info("查询当前排班医生信息serviceConfigEntity={}", serviceConfigEntity);
        if (Objects.nonNull(serviceConfigEntity) && serviceConfigEntity.getOfficeStatus().equals(-1)) {
            serviceConfigEntity.setOfficeStatus(1);
            serviceConfigMapper.updateById(serviceConfigEntity);
        }

        log.info("当前下单的医生:{}", JSON.toJSONString(scheduleRecordEntity));
        return scheduleRecordEntity;
    }


    /**
     * 查询患者签名信息
     *
     * @param phone
     * @param packageOrderId
     * @param signStatus
     * @param status
     * @return
     */
    List<PatientSignEntity> getPatientSignList(String phone, String packageOrderId, Integer signStatus, Integer status) {
        QueryWrapper<PatientSignEntity> psWrapper = new QueryWrapper<>();
        PatientSignEntity patientSign = new PatientSignEntity();
        patientSign.setPatientPhone(phone);
        patientSign.setPackageOrderId(packageOrderId);
        patientSign.setSignStatus(signStatus);
        patientSign.setStatus(status);
        psWrapper.setEntity(patientSign);
        psWrapper.orderByDesc("create_time");
        List<PatientSignEntity> patientSignEntities = patientSignMapper.selectList(psWrapper);
        return patientSignEntities;
    }
}
