package com.ebaiyihui.family.doctor.server.util;

import com.alibaba.fastjson.JSONArray;
import com.ebaiyihui.family.doctor.common.vo.ImInfoListResVo;
import com.fasterxml.jackson.core.JsonFactory;
import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.databind.DeserializationFeature;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.type.CollectionType;

import java.io.IOException;
import java.io.StringWriter;
import java.util.*;
import java.util.stream.Collectors;

/**
 * @ClassName: JsonUtil
 * @Author:yanliang
 * @Date:2024/3/13 11:23
 * @Description
 */

public class JsonUtil {

    private static ObjectMapper mapper = new ObjectMapper();

    @SuppressWarnings("rawtypes")
    public static <T> List<T> convertCollection(String json, Class<? extends Collection> collection, Class<T> clazz) {
        try {
            mapper.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
            CollectionType javaType = mapper.getTypeFactory().constructCollectionType(collection, clazz);
            return (List) mapper.readValue(json, javaType);
        } catch (Exception var4) {
            var4.printStackTrace();
            return null;
        }
    }

    public static <T> T convertObject(String json, Class<T> clazz) {
        try {
            mapper.configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, false);
            return mapper.readValue(json, clazz);
        } catch (Exception var3) {
            var3.printStackTrace();
            return null;
        }
    }

    public static String convertObject(Object object) {
        try {
            return mapper.writeValueAsString(object);
        } catch (Exception var2) {
            var2.printStackTrace();
            return null;
        }
    }


    /**
     * 对象转换为json字符串
     */
    public static String toJson(Object bean) {
        String json = null;
        JsonGenerator gen = null;
        StringWriter sw = new StringWriter();
        try {
            gen = new JsonFactory().createGenerator(sw);
            mapper.writeValue(gen, bean);
            json = sw.toString();
        } catch (IOException e) {
            e.printStackTrace();
            return null;
        } finally {
            try {
                if (gen != null) {
                    gen.close();
                }
                if (sw != null) {
                    sw.close();
                }
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
        return json;
    }

    /**
     * json 转 List<T>
     */
    public static <T> List<T> json2ListBean(String jsonString, Class<T> clazz) {
        @SuppressWarnings("unchecked")
        List<T> ts = (List<T>) JSONArray.parseArray(jsonString, clazz);
        return ts;
    }

    /**
     * string转list集合，使用，进行分隔
     *
     * @param strs
     * @return
     */

    public static List<String> stringToList(String strs) {
        String[] str = strs.split(",");
        return Arrays.asList(str);
    }

    public static void main(String[] args) {
        List<ImInfoListResVo> records = new ArrayList<>();
        ImInfoListResVo imInfoListResVo = new ImInfoListResVo();
        imInfoListResVo.setPatientId("1111");
        imInfoListResVo.setAdmId("22222");
        records.add(imInfoListResVo);
        ImInfoListResVo imInfoListResVo2 = new ImInfoListResVo();
        imInfoListResVo2.setPatientId("1111");
        imInfoListResVo2.setAdmId("33333");
        records.add(imInfoListResVo2);
        ImInfoListResVo imInfoListResVo3 = new ImInfoListResVo();
        imInfoListResVo3.setPatientId("2222");
        imInfoListResVo3.setAdmId("33333");
        records.add(imInfoListResVo3);
        Map<String, List<ImInfoListResVo>> collect =
                records.stream().collect(Collectors.groupingBy(ImInfoListResVo::getPatientId));
        System.out.println(collect);
    }
}
